@@ -3,17 +3,17 @@
 #' This function converts the grouped peak data to a matrix.
 #' The matrix has features (peaks groups) in the columns and the value of the peak for every sample in the rows. 
 #'
-#' @param Y.data The dataset after (at least) peak detection and grouping with speaq 2.0. The dataset after peak filling is recomended.
+#' @param Y.data The dataset after (at least) peak detection and grouping with speaq 2.0. The dataset after peak filling is recommended.
 #' @param var The variable to be used in the Featurematrix. This can be any of 'peakIndex', 'peakPPM', 'peakValue' (default), 'peakSNR', 'peakScale', or 'Sample'.
-#' @param impute What to impute when a certain peak is missing for a certain sample and feature combo. Options are 'zero' (or 'zeros'), mean (imputetion with mean), randomForest (imputation with missForest function from package missForest) or kNN followed by a number indicating the amount of neighbours to use e.g. kNN5 or kNN10 (as per the method of Troyanskaya, 2001). Any other statement will produce NA's.
+#' @param impute What to impute when a certain peak is missing for a certain sample and feature combo. Options are 'zero' (or 'zeros'), median (imputation with median), randomForest (imputation with missForest function from package missForest) or kNN followed by a number indicating the amount of neighbours to use e.g. kNN5 or kNN10 (as per the method of Troyanskaya, 2001). Any other statement will produce NA's.
 #' @param delete.below.threshold Whether to ignore peaks for which the 'var' variable has a value below 'baselineThresh' (default = FALSE).
-#' @param baselineThresh The threshold for the 'var' variable peaks have to surpass to be included in the feature matrix.
+#' @param baselineThresh The threshold for the 'var' variable that peaks have to surpass to be included in the feature matrix.
 #' @param snrThres The threshold for the signal-to-noise ratio of a peak.
-#' @param thresholds.pass This variable lets users deside whether a peak has to pass all the thresholds (both snrThres and baselineThresh), or just one. (If the peak does not need to surpass any thresholds set 'delete.below.threshold' to FALSE). 
+#' @param thresholds.pass This variable lets users decide whether a peak has to pass all the thresholds (both snrThres and baselineThresh), or just one. (If the peak does not need to surpass any thresholds set 'delete.below.threshold' to FALSE). 
 #' 
 #' @references Olga Troyanskaya, Michael Cantor, Gavin Sherlock, Pat Brown, Trevor Hastie, Robert Tibshirani, David Botstein and Russ B. Altman, Missing value estimation methods for DNA microarrays BIOINFORMATICS Vol. 17 no. 6, 2001 Pages 520-525
 #' 
-#' @return a matrix, data.matrix, with samples for rows and features for columns. The values in the matrix are thoes of the 'var' variable.
+#' @return a matrix, data.matrix, with samples for rows and features for columns. The values in the matrix are those of the 'var' variable.
 #'
 #' @author Charlie Beirnaert, \email{charlie.beirnaert@@uantwerpen.be}
 #'
@@ -111,9 +111,9 @@ BuildFeatureMatrix <- function(Y.data, var = "peakValue", impute = "zero", delet
     colnames(data.matrix) <- Features
     rownames(data.matrix) <- Samples
     
-    if (impute == "mean") {
+    if (impute == "median") {
         for (k in 1:nFeatures) {
-            data.matrix[is.na(data.matrix[, k]), k] <- mean(data.matrix[!is.na(data.matrix[, k]), k])
+            data.matrix[is.na(data.matrix[, k]), k] <- median(data.matrix[!is.na(data.matrix[, k]), k])
         }
     } else if(length(grep("kNN",  impute)) > 0){
         data.matrix <- impute::impute.knn(data.matrix, k = as.numeric(gsub("kNN","", impute)), rowmax = 0.5, colmax = 0.8, maxp = 1500)
