@@ -4,7 +4,7 @@
 #'
 #' @param Y.spec (required) The raw spectra in matrix format (1 sample per row) or numeric vector (in case of 1 spectrum)
 #' @param X.ppm (required) The vector with the ppm values
-#' @param ungrouped.peaks (required) The data resulting from peak detecion with wavelets
+#' @param ungrouped.peaks (required) The data resulting from peak detection with wavelets
 #' @param grouped.peaks (required) The data after grouping (with PeakGrouper)
 #' @param ROI If provided (with an index value, not a ppm value) only this region of interest will be plotted. (supply no ROI or ROI.ppm values, for the full spectrum, or specify only 1, either ROI or ROI.ppm).
 #' @param ROI.ppm If provided (a ppm value, not an index value) only this region of interest will be plotted. (supply no ROI or ROI.ppm values, for the full spectrum, or specify only 1, either ROI or ROI.ppm).
@@ -31,8 +31,8 @@
 #'                            
 #' ROI.ppm <- 4.9
 #' roiWidth.ppm <- 0.15
-#'
-#' plots <- ROIplot(Y.spec = subset.spectra, 
+#' 
+#' plots <- ROIplot(Y.spec = subset.spectra,
 #'                  X.ppm =subset.ppm, 
 #'                  ungrouped.peaks = test.peaks,
 #'                  grouped.peaks = test.grouped ,
@@ -100,6 +100,7 @@ ROIplot <- function(Y.spec, X.ppm, ungrouped.peaks, grouped.peaks, ROI = NULL, R
             })
         }
     }
+    rownames(Y.spec) = groupLabels
     
     if(is.null(output)){
          
@@ -151,7 +152,7 @@ ROIplot <- function(Y.spec, X.ppm, ungrouped.peaks, grouped.peaks, ROI = NULL, R
     names(ROI.df) <- c("ppm", "sample", "intensity")
     ROI.df$class <-  groupLabels[ROI.df$sample]
 
-    pp0 <- ggplot(ROI.df, aes_string(x = "ppm", y = "intensity", group = "sample", colour = "class")) +
+    pp0 <- ggplot(ROI.df, aes_string(x = "ppm", y = "intensity",  colour = "class")) +
            scale_x_reverse()+
            theme_bw() +
            geom_line(size = 0.3) +
